package com.goldenwater.gx.service;

import java.util.List;
import com.goldenwater.gx.domain.GxExchangeStation;

/**
 * 数据交换站点Service接口
 */
public interface IGxExchangeStationService
{
    public GxExchangeStation selectGxExchangeStationById(Long id);

    public List<GxExchangeStation> selectGxExchangeStationList(GxExchangeStation station);

    public List<GxExchangeStation> selectStationByBizCode(String bizCode);

    public int insertGxExchangeStation(GxExchangeStation station);

    public int updateGxExchangeStation(GxExchangeStation station);

    public int deleteGxExchangeStationByIds(Long[] ids);

    public int deleteGxExchangeStationById(Long id);

    /**
     * 导入站点数据
     *
     * @param stationList 站点数据列表
     * @param updateSupport 是否更新已存在数据
     * @param operName 操作人
     * @return 结果信息
     */
    public String importStation(List<GxExchangeStation> stationList, Boolean updateSupport, String operName);
}
